ggstats_add_xy<-function(table_stat, table, xcol=NULL, group, y="max", bracket.offset=0.05, bracket.inspace=0.05, exclude_group=NULL, dodge=0.75){
  ## Adapted version to fit rstatix output
  value.var<-table_stat[[1,".y."]]
  if (is.null(xcol)){
    x<-colnames(table_stat)[1]
  }else{x<-xcol}

  if(!is.null(group)){table[,group]<-as.factor(pull(table,group))}
  table[,x]<-as.factor(pull(table,x))
  if (is.null(exclude_group)){
    table_agg<-table %>% group_by(.data[[x]])
  }else{
    table_agg<-table %>% group_by(.data[[x]], !!!syms(exclude_group))
  }
  if (y == "max"){
    agg<-table_agg %>% summarise(max=max(.data[[value.var]], na.rm = T))
    if(!is.null(exclude_group)){agg<-table_agg %>% group_by(!!!syms(exclude_group)) %>% summarise(max=max(.data[[value.var]], na.rm=T))}
  }else if (y == "mean"){
    agg<-table %>% group_by(.data[[x]],.data[[group]]) %>% summarise(mean=mean(.data[[value.var]], na.rm=T)) %>% spread(group, mean)
    agg<- data.frame(x=agg[,1], "max"=apply(agg[,2:ncol(agg)], 1, max, na.rm=T))
    colnames(agg)[1]<-x
  }else if (y == "mean+sd"){
    agg<-table %>% group_by(.data[[x]],.data[[group]]) %>% summarise(mean=mean(.data[[value.var]], na.rm=T)+sd(.[[value.var]], na.rm=T)) %>% spread(group, mean)
    agg<- data.frame(x=agg[,1], "max"=apply(agg[,2:ncol(agg)], 1, max, na.rm=T))
    colnames(agg)[1]<-x
  }else if (y == "mean+sem"){
    agg<-table %>% group_by(.data[[x]],.data[[group]]) %>% summarise(mean=mean(.data[[value.var]], na.rm=T)+sem(.[[value.var]], na.rm=T)) %>% spread(group, mean)
    agg<- data.frame(x=agg[,1], "max"=apply(agg[,2:ncol(agg)], 1, max, na.rm=T))
    colnames(agg)[1]<-x
  }

  group.list<-list()
  count<-1
  if(!is.null(group)){table_stat<-mutate(table_stat, {{x}}:=as.factor(.data[[x]]))}

  for (i in 1:nrow(table_stat)){
    group.list[[count]]<-c(table_stat %>% slice(i) %>% pull(group1),table_stat%>% slice(i) %>% pull(group2))
    count<-count+1
  }
  if(!is.null(group)){
    x.index<-sapply(table_stat %>% pull(x), function(y) which(levels(table_stat %>% pull(x)) == y))
    t<-tibble("y.position"=merge(table_stat, agg ,sort=F)[,"max"]+diff(range(table[value.var], na.rm = T))*bracket.offset,
              "groups"=group.list,
              "x.temp"=x.index,
              "xmin"=(match(table_stat %>% pull(x), levels(table[,x]))+dodge*((match(table_stat$group1, levels(table[,group]))-0.5)/length(levels(table[,group]))-0.5)),
              "xmax"=match(table_stat %>% pull(x), unique(table[,x]))+dodge*((match(table_stat$group2, levels(table[,group]))-0.5)/length(levels(table[,group]))-0.5)
    ) %>% rename("x"="x.temp")
  }else{
    t<-tibble("y.position"=merge(table_stat, agg ,sort=F)[,"max"]+diff(range(table[value.var], na.rm = T))*bracket.offset,
              "groups"=group.list,
              # "x.temp"=x.index,
    )# %>% rename("x"="x.temp")
  }
  if (!is.null(group)){
    if (!is.null(exclude_group)){
      for (j in unique(pull(table_stat, all_of(exclude_group)))){
        for (dia in unique(pull(table_stat,all_of(xcol)))){
          if (table_stat %>% filter(p < 0.05) %>% filter(.data[[x]] == dia & .data[[exclude_group]] == j) %>% nrow() > 0){
            t[table_stat[,x] == dia & table_stat[,exclude_group] == j,"y.position"]<-seq(t[table_stat[,x] == dia & table_stat[,exclude_group] == j,"y.position"][[1,1]],
                                                                                         t[table_stat[,x] == dia & table_stat[,exclude_group] == j,"y.position"][[1,1]]+diff(range(table[,value.var], na.rm = T))*bracket.inspace*(nrow(table_stat[table_stat[,x] == dia & table_stat[,exclude_group] == j,])-1),
                                                                                         by=diff(range(table[,value.var], na.rm = T))*bracket.inspace)
          }
        }
      }
    }else{
      for (dia in unique(pull(table_stat,all_of(xcol)))){
        t[table_stat[,x] == dia,"y.position"]<-seq(t[table_stat[,x] == dia,"y.position"][[1,1]],
                                                   t[table_stat[,x] == dia,"y.position"][[1,1]]+diff(range(table[,value.var], na.rm = T))*bracket.inspace*(nrow(table_stat[table_stat[,x] == dia,])-1),
                                                   by=diff(range(table[,value.var], na.rm = T))*bracket.inspace)
      }
    }
  }else{
    for (dia in unique(pull(mutate(table_stat,dia=paste0(!!!syms(exclude_group))),dia))){
      t[apply(table_stat[,exclude_group], 1, paste, collapse="") == dia, "y.position"]<-seq(t[apply(table_stat[,exclude_group], 1, paste, collapse="") == dia,"y.position"][[1,1]],
                                                                                            t[apply(table_stat[,exclude_group], 1, paste, collapse="") == dia,"y.position"][[1,1]]+
                                                                                              diff(range(table[,value.var], na.rm = T))*
                                                                                              bracket.inspace*(nrow(table_stat[apply(table_stat[,exclude_group], 1, paste, collapse="") == dia,])-1),
                                                                                            by=diff(range(table[,value.var], na.rm = T))*bracket.inspace)
    }
  }
  return(cbind(table_stat,t) %>% as_tibble)
}
